User Guide
----------
The user guide provides in-depth information on the key concepts of the library with 
useful background information and explanation.

.. toctree::
    :maxdepth: 2
    
    notebooks/points_and_pointclouds
    notebooks/mesh_composition
    notebooks/mesh_structure
    notebooks/plotting
    notebooks/grids
    notebooks/trafo_geom
    notebooks/trafo_topo
    notebooks/data
    notebooks/io
    notebooks/mesh_analysis
    notebooks/shape_function_generation
    notebooks/approximation